
### PyTransifex: yet another Python Transifex API

Read the documentation: https://opengisch.github.io/pytransifex

This was largely based on https://github.com/jakul/python-transifex which was not made available for Python 3.
